;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x298be0c278a37198ec793ef47abd8ffb . "./code.cg2js/cg-status-bar.fasl")
(#xddee7aa0feb72d3347bf8cdf00a49425 . "./code.cg2js/cg-hotspot.fasl")
(#x7bda484e7bf5e0ce63071315fa41c379 . "./code.cg2js/cg-toolbar.fasl")
(#x460704ae740fa794eb9282a082cb3b75 . "./code.cg2js/cg-clipboard-stack.fasl")
(#xf675a233fe53d0877d824d200375bb63 . "./code.cg2js/cg-tooltip.fasl")
(#xd04871b5966651b3e52e5ba45c11b326 . "./code.cg2js/cg-calendar.fasl")
(#xbd1b1647bb5405e02a27f2917a6242d9 . "./code.cg2js/cg-item-list.fasl")
(#x19b5d51853402075cfde9fbcb0c9182c . "./code.cg2js/cg-bitmap-stream.fasl")
(#x359167052b4315178ada1ae9d6768608 . "./code.cg2js/cg-trackbar.fasl")
(#xee9b9e3e178f2af140a83ac53fe323fa . "./code.cg2js/cg-class-grid.fasl")
(#x494d8bd13e4fa8f8cc81030ca6881b90 . "./code.cg2js/cg-dialog-item.fasl")
(#x5c8da0b695fd567c5932d58f329c7ccb . "./code.cg2js/cg-comtab.fasl")
(#xceca15852f7944e56f0ffe522616bde1 . "./code.cg2js/cg-lisp-text.fasl")
(#x1e25bdb30e675a93a9d69810c732f025 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x7f6b13b3c88270b474a5ded49cfb257c . "./code.cg2js/cg-button.fasl")
(#xcf1280db627167cf6d0cc5156ba4d6b2 . "./code.cg2js/cg-printing.fasl")
(#xe04b842ee11de824cbe24793809bee3c . "./code.cg2js/cg-pixmap-printing.fasl")
(#xdc41ef059f740dffb2ef41085aeb2671 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x8f7d83013e4733f5e0b3dbb26988c42d . "./code.cg2js/cg-pixmap-widget.fasl")
(#xee138cb06ff2f9a5ce5dc02c2803d5bb . "./code.cg2js/cg-selected-object.fasl")
(#xfc8d3aea286dd263b58df38df9058b63 . "./code.cg2js/cg-text-or-combo.fasl")
(#x40396cd09684f58a97724eb29c3f1f01 . "./code.cg2js/cg-graphics-context.fasl")
(#x611d2bc09260c6defc44a57eaa36d3e6 . "./code.cg2js/cg-edit-in-place.fasl")
(#xb8afb867e8b365bd192664f6a63d8c67 . "./code.cg2js/cg-string-dialog.fasl")
(#x1524514a1e347b26e6568b9e52bce5a9 . "./code.cg2js/cg-list-view.fasl")
(#x4522215f0a69fda05d9b9092a35d3562 . "./code.cg2js/cg-intersect.fasl")
(#x5f7abb17c9d6fba1bca963f148ca7042 . "./code.cg2js/cg-text-widget.fasl")
(#x2cc94fd75be6da91464528192c731b01 . "./code.cg2js/cg-directory-dialog.fasl")
(#x6691c9db9cc35269abfb5d1fd7f72dfe . "./code.cg2js/cg-file-dialog.fasl")
(#xf2f3321e84e448c9bb91c69cb77813e1 . "./code.cg2js/cg-dde-utils.fasl")
(#xec640f3e1b162a9ef69d8a829db5d42a . "./code.cg2js/cg-nodes.fasl")
(#x832ff67719fc81a3d7d15f570cece58c . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x2124d9d18ef9f830e1cae640a3902e85 . "./code.cg2js/cg-up-down-control.fasl")
(#x83bfa6bd7b0a81cbd951b11bef408b48 . "./code.cg2js/cg-get-position.fasl")
(#xdff8ef5ccf9526e9334bf295c31e5cf8 . "./code.cg2js/cg-toggling-widget.fasl")
(#x3f98cc4571ea7889d836b36f7d9610e7 . "./code.cg2js/cg-acache.fasl")
(#x5e3a264c18f4c09115704b80b3e9c815 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#xfe8d880e707323e69132a2d3691f8a75 . "./code.cg2js/cg-base.fasl")
(#x018b78f1921d582c2b91ceefc9b1917c . "./code.cg2js/cg-drag-and-drop.fasl")
(#x1360713477098baa64845c1a073b4bd3 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x6601c438f14816a0a87788973c863e23 . "./code.cg2js/cg-property.fasl")
(#xa3ff7eda2635ef58f99fb4c8a2cd0429 . "./code.cg2js/cg-editable-text.fasl")
(#xcc95a541d79a299f1c3e1a83c569b592 . "./code.cg2js/cg-lamp.fasl")
(#x4d4d9e4d2729184166859e100359a8bb . "./code.cg2js/cg-progress-indicator.fasl")
(#xe40aab32057c4e166fc3ddc47272d348 . "./code.cg2js/cg-chart-widget.fasl")
(#x98ead194d19cdf82f3bb58091ba703fc . "./code.cg2js/cg-common-control.fasl")
(#xdf144e7dcf6e13e40f7b65fba6e1d254 . "./code.cg2js/cg-font-dialog.fasl")
(#x31362e11f152a7e3edc25a8b1decfcae . "./code.cg2js/cg-gesture-emulation.fasl")
(#xdb7b929b1c34a1a8bd26cebc7f211dec . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x3dc18148a5e5ff9ca6c40af2c4672882 . "./code.cg2js/cg-os-window.fasl")
(#xa9cabe2239cd92e3b027cfa7423f208e . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x53563745a752294133b210b5a5a3eb02 . "./code.cg2js/cg-pixmap.fasl")
(#xc1ba16cabdfe89bb9778d7d20401f1f9 . "./code.cg2js/cg-chart-or-plot.fasl")
(#xa95621257bacb909cc1d7b6f97823825 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xeba18e94a20d96104cfbe52b9b1e7c46 . "./code.cg2js/cg-scaling-stream.fasl")
(#x08f7e9590ed4e51d7435cb7ed0d50e25 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xd9ffa05619aebc4198f5d3a67a974708 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x626482595a85d3f51a9f38a2fb2c0f07 . "./code.cg2js/cg-timer.fasl")
(#x01052b8cc2a6c8c375f14751aa30414b . "./code.cg2js/cg-scroll-bar.fasl")
(#xbdf9661ff78a3ccfa2e8009b48a1f778 . "./code.cg2js/cg-caret.fasl")
(#x9b8887cbe085d42f6eb49735a8908cd8 . "./code.cg2js/cg-template-string.fasl")
(#x05dbeae84425d87998b56da511eb8069 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xac02e01d64133331804d944ac5e5f009 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x82b3c631ddf33a33a1eccf4cc6b3b2cf . "./code.cg2js/cg-rich-edit.fasl")
(#x36819e68afd9da74eb8ac76e82d84573 . "./code.cg2js/cg-combo-box.fasl")
(#x9584a1d35628e294f70857a83d601164 . "./code.cg2js/cg-text-edit-pane.fasl")
(#xea4321de7cea1241a8207f466779b532 . "./code.cg2js/cg-multi-picture-button.fasl")
(#xadc1798ea4611ca913f2d5fb3877612a . "./code.cg2js/cg-menu-tooltip.fasl")
(#x09921fee9b95e9e2dd750598a929340c . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xa462a3332b808468dec4f44fd5941898 . "./code.cg2js/cg-outline.fasl")
(#x75fc74834f38282c43dd6e3e967b6c05 . "./code.cg2js/cg-class-support.fasl")
(#x1052b42f633ae3c6b9a6f7b371a42de5 . "./code.cg2js/cg-header-control.fasl")
(#xba3f7f691ba72781c3b5f1bdc85aa71b . "./code.cg2js/cg-lettered-menu.fasl")
(#xe3470113656144077f2b8517c52788e5 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xf6b1ddedcf35b5ffbde0eab4cc5fe246 . "./code.cg2js/cg-fill-texture.fasl")
(#xdb37481c72e3695d5885349b47b82ff5 . "./code.cg2js/cg-lisp-widget.fasl")
(#x4debb490cf4e333b7a97bda0597b335b . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#xc1593928d6469d0f756455476a302a2a . "./code.cg2js/cg-clipboard.fasl")
(#x563babe97983a9050add428b4d2586d9 . "./code.cg2js/cg-wrap-string.fasl")
(#xe025f8281e986eb192ae3736f2863a19 . "./code.cg2js/cg-os-widget.fasl")
(#xdb47df180f0bae574e131d1c26f22356 . "./code.cg2js/cg-check-box.fasl")
(#x1532ed6def864af12528934781600422 . "./code.cg2js/cg-choice-list.fasl")
(#x1967c618c03c90411ba4e6a85a643420 . "./code.cg2js/cg-layout.fasl")
(#x34f53f293e8dc39b543b5f8d521080fa . "./code.cg2js/cg-group-box.fasl")
(#x564b030107a8b6f0398ad52142374837 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x3192c3bf5360c50abeaed0cdce58e45a . "./code.cg2js/cg-radio-button.fasl")
(#x1bed5f37f43740a2a344313762165785 . "./code.cg2js/cg-tab-control.fasl")
(#x35f58926cd2ab2447d97f9f8b7ba9b08 . "./code.cg2js/cg.fasl")
(#x400a8325b9c19e83895c85f40e17a3d0 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x82cbca5cc97c0fb39db5fbd8c58a6ad3 . "./code.cg2js/cg-dropping-outline.fasl")
(#xa03aecfa82bfd94b3c972652236e3d30 . "./code.cg2js/cg-get-pixmap.fasl")
(#x9b85721beac2ea5ea3be87f4993ed1ae . "./code.cg2js/cg-grid-widget.fasl")
(#x14f2d92e04eb7a974a5b8cdce4c66ef3 . "./code.cg2js/cg-utility-dialog.fasl")
(#x12d093d593c7fbc5f171bf43db2814d8 . "./code.cg2js/cg-static-text.fasl")
(#x69917e7ee83a8138a5fd7cdc14a5c12e . "./code.cg2js/cg-class-slot-grid.fasl")
(#x28a38e2535e36dcae592ff052c977012 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x26c79ddc774438b9557ef3c11b3603b5 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x177f28a406582e516e094ef466f196c4 . "./code.cg2js/cg-bitmap-pane.fasl")
(#xd6c4e1762fd1123d71cf9e2938545fc5 . "./code.cg2js/cg-plot-widget.fasl")
(#x33e49aabbaa988236f062744446eeab4 . "./code.cg2js/cg-color-dialog.fasl")
(#x88fccfc68fcfa164b22278646575437b . "./code.cg2js/cg-icon-pixmap.fasl")
(#x6efa093432e51571b275a2255b470d36 . "./code.cg2js/cg-icon.fasl")
(#x2c126a04eb318bd9d1340f2088c75464 . "./code.cg2js/cg-dev.fasl")
(#x51edddbc72d30329f3cb92d5c21e6de2 . "./code.cg2js/cg-choose-printer.fasl")
(#x5395c57f0def1c2ebc30b77046eb2f13 . "./code.cg2js/cg-intersect-posbox.fasl")
(#x3b41d6ade9f0b58861410291bf0133aa . "./code.cg2js/cg-menu.fasl")
(#x7a21497708471736c24f6cf5eed3cc75 . "./code.cg2js/cg-yes-no-list.fasl")
(#x364b2a602c387bc3db1f0d976d9dce01 . "./code.cg2js/cg-palette.fasl")
(#xe79973239e4e17d973d8c93bcbfa2f3b . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#xd1bbe8d96c5fb1472d38dd95e8901691 . "./code.cg2js/cg-message-dialog.fasl")
(#x5dd96e66c7a7e173b0c9f5d1f8a03314 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x7270b2219dfa3e6fb483fc07eea9d455 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x65cceab84316086ab1fb9cf7ec05f20f . "./code.cg2js/cg-split-bar.fasl")
(#xdc7742e27aa2646402476648219d3014 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#xba24b73e23d23ef7fa1f27c82428b39d . "./code.cg2js/cg-web-browser.fasl")
(#xc06e3e77fca3f053631e8bc89ab2b81e . "./code.cg2js/cg-project-window.fasl")
(#x103e5eb111c7cb07093c9962137929c2 . "./code.cg2js/cg-picture-widget.fasl")
(#xb04a4caab8879eea3862b3e2bccf692d . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xad6758d8688b69d922182eb4fe1f6d9f . "./code.cg2js/cg-object-editor.fasl")
(#x058bc568d6651042c9dc1ed85416eca4 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x2f186b5b8d2899b39dcfd84685f53868 . "./code.cg2js/cg-paren-matching.fasl")
(#xe74e8d1065b30f365a366735e71b288c . "./code.cg2js/cg-sample-file-menu.fasl")
(#xdbb74440970febaac13c46d98078993a . "./code.cg2js/cg-drawable.fasl")
(#x383d65f075735e3fcc68a038164232ec . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x5256d31bf99257e6d6a5fe5e49a85ca7 . "./code.cg2js/cg-html-widget.fasl")
(#x73c2a73f8576a6bd6ccb55bb536e1b44 . "./code.cg2js/cg-curve.fasl")
(#xb88ee7f4caaff5e0a1460b56ab4d8971 . "./code.cg2js/cg-yes-no-string.fasl")
(#x0e7a05534266e408b8359e631fc98d8b . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#xd22cc49105e261dc3acbcdaf866a2fc0 . "./code.cg2js/cg-html-dialog.fasl")
(#xc691219c98b70bb4ba4fa6c58820608e . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x85bf6093b74db558bc98ca8337a5c47d . "./code.cg2js/cg-tray.fasl")
(#x1086990ef6aa385eb2a2627c4d68d344 . "./code.idejs/ide-apropos.fasl")
(#x08e7d8c77264ac73045617ad0ce34734 . "./code.idejs/ide-window-list.fasl")
(#x964063253c12691356bb7ee39cf04f59 . "./code.idejs/ide-class-browser.fasl")
(#xfcc5eb416d44d39fad853ca058d1d7ac . "./code.idejs/ide-base.fasl")
(#x653ab67f35dc4de0d316c26c6973cf6d . "./code.idejs/ide-process-browser.fasl")
(#x3378250e01a7b99b3500e8dfda0b2f1d . "./code.idejs/ide-acache.fasl")
(#x438496e6c1d350508fb4f9617d28ab2e . "./code.idejs/ide-navigator.fasl")
(#x5c0c69cc132efba39ac0a88886c5291e . "./code.idejs/ide-trace.fasl")
(#x39c71f6fc4b296dec39fc19e1a050ac3 . "./code.idejs/ide-project.fasl")
(#xe9b7ef6e3d9dfa3fe8adf4e27409a3c4 . "./code.idejs/ide-patch-dialog.fasl")
(#xd9cb07cebd18f0c003a29786f368f079 . "./code.idejs/ide-grapher.fasl")
(#x3a19444633b1edf44ddb37c04cdc755c . "./code.idejs/ide-dev.fasl")
(#x4e0e79a1a813bd82275545f830af26df . "./code.idejs/ide-keyshort.fasl")
(#x1b4cc72333e039501523e594a08ba920 . "./code.idejs/ide-editor.fasl")
(#xbb5c9a0b04c023862c0e548f7f4fbe24 . "./code.idejs/ide-inspector.fasl")
(#x5e793c4723417e95b9cd788c086a1350 . "./code.idejs/ide.fasl")
(#x665c0483a5f3705046308a65915ddc63 . "./code.idejs/ide-clipboard.fasl")
(#xa53bbbaafea42121b986aaa01c7713b4 . "./code.idejs/ide-find-definitions.fasl")
(#xdc1000199c5ad4ae44f13a0345a13722 . "./code.idejs/ide-form.fasl")
(#x5dbc3cba9778196a7fe6f34a3f428b7d . "./code.idejs/ide-intro.fasl")
(#x0f66feaa6590cdfb933132b0bcc28403 . "./code.idejs/ide-find-in-files.fasl")
(#xdc97a085cdd37d3c62a39eb14fa34025 . "./code.idejs/ide-package-list.fasl")
(#xb724b988743d52447a120a6a28af8025 . "./code.idejs/ide-class-grapher.fasl")
(#xeb5b70ef6a4ced03becd92b82d3b0061 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
